pub struct RewardServiceClient<T> {
inner: Grpc<T>,
}Expand description
gRPC service for reward state queries
Fields
inner: Grpc<T>Implementations
Sourceimpl RewardServiceClient<Channel>
impl RewardServiceClient<Channel>
Sourceimpl<T> RewardServiceClient<T>
impl<T> RewardServiceClient<T>
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> RewardServiceClient<InterceptedService<T, F>>
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn get_reward_claim_input(
&mut self,
request: impl IntoRequest<GetRewardClaimInputRequest>,
) -> Result<Response<RewardClaimInput>, Status>
pub async fn get_reward_claim_input( &mut self, request: impl IntoRequest<GetRewardClaimInputRequest>, ) -> Result<Response<RewardClaimInput>, Status>
Get reward claim input for L1 contract submission (at latest finalized height)
Sourcepub async fn get_reward_balance(
&mut self,
request: impl IntoRequest<GetRewardBalanceRequest>,
) -> Result<Response<RewardBalance>, Status>
pub async fn get_reward_balance( &mut self, request: impl IntoRequest<GetRewardBalanceRequest>, ) -> Result<Response<RewardBalance>, Status>
Get reward balance (at latest finalized height)
Sourcepub async fn get_reward_account_proof(
&mut self,
request: impl IntoRequest<GetRewardAccountProofRequest>,
) -> Result<Response<RewardAccountQueryDataV2>, Status>
pub async fn get_reward_account_proof( &mut self, request: impl IntoRequest<GetRewardAccountProofRequest>, ) -> Result<Response<RewardAccountQueryDataV2>, Status>
Get Merkle proof for reward account (at latest finalized height)
Sourcepub async fn get_reward_balances(
&mut self,
request: impl IntoRequest<GetRewardBalancesRequest>,
) -> Result<Response<RewardBalances>, Status>
pub async fn get_reward_balances( &mut self, request: impl IntoRequest<GetRewardBalancesRequest>, ) -> Result<Response<RewardBalances>, Status>
Get paginated list of reward balances at a specific height
Sourcepub async fn get_reward_merkle_tree_v2(
&mut self,
request: impl IntoRequest<GetRewardMerkleTreeRequest>,
) -> Result<Response<RewardMerkleTreeV2Data>, Status>
pub async fn get_reward_merkle_tree_v2( &mut self, request: impl IntoRequest<GetRewardMerkleTreeRequest>, ) -> Result<Response<RewardMerkleTreeV2Data>, Status>
Get raw RewardMerkleTreeV2 snapshot at a specific height